@@ -1,5 +1,5 @@
 import buildflaskapp
-from scripts.workflow import get_app_name, is_name_valid
+from buildflaskapp.scripts.workflow import get_app_name, is_name_valid
 from scripts.workflow import get_args,  is_args_valid
 from scripts.workflow import create_dir, create_app, create_templates_folder, create_static_folder, create_dockerfile
 from scripts.manual import print_manual
